==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+88"/>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exporter en bitmap</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Erreur lors de la génération du fichier bitmap &apos;%1&apos;: &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fichier Bitmap a été exportée vers &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Erreur lors de la génération du fichier Bitmap &quot;%1&quot; : &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Fichier Bitmap a été exportée vers &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Exporter en bitmap...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exporter en bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largeur : </translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Hauteur : </translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixels par unité de dessin :</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Marge :</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Blanc</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Noir</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/BitmapExport/ts/BitmapExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BitmapExport</name>
    <message>
        <location filename="../BitmapExport.js" line="+105"/>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Export as Bitmap</source>
        <translation>Exporter en bitmap</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Error while generating Bitmap file &apos;%1&apos;: %2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Erreur lors de la génération du fichier bitmap &apos;%1&apos;: &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Bitmap file has been exported to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fichier Bitmap a été exportée vers &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while generating Bitmap file &quot;%1&quot;: %2</source>
        <translation type="obsolete">Erreur lors de la génération du fichier Bitmap &quot;%1&quot; : &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Bitmap file has been exported to &quot;%1&quot;</source>
        <translation type="obsolete">Fichier Bitmap a été exportée vers &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../BitmapExportInit.js" line="+2"/>
        <source>Bit&amp;map Export...</source>
        <translation>&amp;Exporter en bitmap...</translation>
    </message>
    <message>
        <location filename="../BitmapExportDialog.ui" line="+14"/>
        <source>Bitmap Export</source>
        <translation>Exporter en bitmap</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largeur : </translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Height:</source>
        <translation>Hauteur : </translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Pixels per drawing unit:</source>
        <translation>Pixels par unité de dessin :</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Margin:</source>
        <translation>Marge :</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>White</source>
        <translation>Blanc</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Black</source>
        <translation>Noir</translation>
    </message>
</context>
</TS>
